Description Usage Arguments Value Functions
Euclidean Function
1 | euclidean(x, y)
|
x, y |
respectively numerical values |
the greatest common divisor of two numbers
euclidean: algoritm to implement is the Euclidian algorithm to nd the greatest common divisor of two numbers. The description of the algorithm with pseudocode can be found here https://en.wikipedia.org/wiki/Euclidean algorithm. Assert that the arguments are numeric scalars or integers.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.